# This module normally gets compiled into a C module to improve the speed.
# Tested with Shedskin 0.6
# In case the module can not be compiled or the file lib/mylib.so is missing,
# python will jump back and use this file (mylib.py) instead.
# This works the same, but might be slower.


def IsCompiled():
    r=True
    #{
    r=False #used to detect if c module is available
    #}
    return r








def sleep_filter(ar, arlen, filter,  shift, Yscale, Yoffset, Ymax, Ymin, limitMovement):
    len_filter=len(filter)

    ar_ret=[0]*(arlen+len_filter)

    for i in range(0, arlen): #loop arrData
        if(ar[i] > limitMovement): #limit peack values
            ar[i] = limitMovement



    for i in range(0, arlen): #loop arrData
        value=ar[i]

        for p in range(0,  len_filter-1): #loop arrFilter
            ar_ret[i+p-shift] = ar_ret[i+p-shift] + value*filter[p]



    for i in range(0, arlen): #loop arrData
        value=(ar_ret[i] * Yscale/80000)-Yoffset #Yscale

        if(value > Ymax): #check range over/unterrun
            ar_ret[i] = Ymax #-int(random.uniform(1, 2))
        elif(value < Ymin):
            ar_ret[i] =Ymin
        else:
            ar_ret[i]=value


    return ar_ret





if __name__ == '__main__':
    #those lines are needed, so Shedskin knows how the parameters of the functions are:
    IsCompiled()
    arTest=[1, 2, 3, 4, 5, 6, 7, 8, 9]
    arFiltertest=[1, 2, 3]
    sleep_filter(arTest, 1, arFiltertest, 1, 20, 10, 120, 13, 250)
